# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-07-12 10:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0010_robocxlview_roboldaview_roboltdview'),
    ]

    operations = [
        migrations.AddField(
            model_name='roboltdview',
            name='ACCRUED_PENAL_INT_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='ADJUST_FROM_SEC_DEP_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='BUILDER_PROFIT_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='COMP_INT_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='DEFERRED_INT_DMD_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='EMICAP_DEFERRED_INT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='INT_REFUND_PREPYMNT_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='MARGIN_MNY_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='NORMAL_PRINCIPAL_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='PEN_ON_INT_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='PEN_ON_PRIN_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='PLANNED_PREPAY_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='PRINCIPAL_OVERDUE_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='RETENTION_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='roboltdview',
            name='WAIVER_RECORD',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='BANK_ID',
            field=models.CharField(max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CHANNEL_ID',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CHRG_ACID',
            field=models.CharField(max_length=44, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CHRG_BORNE_BY_IND',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CHRG_DEBIT_PART_TRAN_SRL_NUM',
            field=models.CharField(max_length=16, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CHRG_PART_TRAN_SRL_NUM',
            field=models.CharField(max_length=16, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CHRG_REVERSAL_REASON_CODE',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CHRG_RPT_CODE',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CHRG_TRAN_ID',
            field=models.CharField(max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='COLL_CRNCY_CODE',
            field=models.CharField(max_length=12, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='COMP_B2KID',
            field=models.CharField(max_length=260, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='COMP_B2KID_TYPE',
            field=models.CharField(max_length=40, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CONSOL_DEBIT_PTRAN_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CUST_ID',
            field=models.CharField(max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='CXL_SRL_NUM',
            field=models.CharField(max_length=48, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='DEFAULT_CHRG_CALC_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='DEL_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='ENTITY_CRE_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='EVENT_ID',
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='EVENT_TYPE',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='GL_SEGMENT_STRING',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='LCHG_USER_ID',
            field=models.CharField(max_length=60, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='LOAN_ACCT_NUM',
            field=models.CharField(max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='MODIFY_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='PARENT_CXL_SRL_NUM',
            field=models.CharField(max_length=48, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='PARENT_TRAN_ID',
            field=models.CharField(max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='PARENT_TRAN_SRL_NUM',
            field=models.CharField(max_length=16, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='PART_CHRG_COLL_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='PART_TRAN_TYPE',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='PTRAN_BUS_TYPE',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='RATE_CODE1',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='RATE_CODE2',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='RCRE_USER_ID',
            field=models.CharField(max_length=60, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='RECORD_TYPE',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='REC_NOT_EFFECTIVE',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='REF_CXL_SRL_NUM',
            field=models.CharField(max_length=48, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='REL_PRICING_REF_NUM',
            field=models.CharField(max_length=48, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='REVERSAL_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='SERVICE_SOL_ID',
            field=models.CharField(max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='SRL_NUM',
            field=models.CharField(max_length=16, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='TARGET_ACID',
            field=models.CharField(max_length=44, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='TRAN_PARTICULAR',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='TRAN_RMKS',
            field=models.CharField(max_length=120, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='WAIVER_REASON_CODE',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='robocxlview',
            name='WAIVER_REMARKS',
            field=models.CharField(max_length=120, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='ACID',
            field=models.CharField(max_length=44, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='BANK_ID',
            field=models.CharField(max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='DEL_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='DMD_FLOW_ID',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='DMD_SRL_NUM',
            field=models.CharField(max_length=8, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='LCHG_USER_ID',
            field=models.CharField(max_length=60, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='LOAN_ACCT_NUM',
            field=models.CharField(max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='OFLOW_ADJ_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='PART_TRAN_SRL_NUM',
            field=models.CharField(max_length=16, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='RCRE_USER_ID',
            field=models.CharField(max_length=60, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='SHDL_NUM',
            field=models.CharField(max_length=8, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='SRL_NUM',
            field=models.CharField(max_length=12, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='TRAN_ID',
            field=models.CharField(max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='WAIVER_RECORD',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboldaview',
            name='WAIVER_SRL_NUM',
            field=models.CharField(max_length=16, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='ACID',
            field=models.CharField(max_length=44, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='ADVANCE_PAYMENT_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='BANK_ID',
            field=models.CharField(max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='DEL_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='DEMAND_IND',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='DMD_OFFSET_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='DMD_SATISFY_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='DMD_SRL_NUM',
            field=models.CharField(max_length=8, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='ENTITY_CRE_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='FLOW_ID',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='INT_BENEFIT_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='INT_COLL_ON_PREPAYMENT_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='LAST_TRAN_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='LCHG_USER_ID',
            field=models.CharField(max_length=60, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='LOAN_ACCT_NUM',
            field=models.CharField(max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='LOAN_INT_ACID',
            field=models.CharField(max_length=44, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='OFLOW_ADJ_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='ORIGIN_OF_TRAN',
            field=models.CharField(max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='PART_TRAN_SRL_NUM',
            field=models.CharField(max_length=16, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='PREPAYMENT_TYPE',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='RAISE_DMD_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='RCRE_USER_ID',
            field=models.CharField(max_length=60, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='REVERSAL_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='REVERSAL_REF_ID',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='REVERSED_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='SHDL_NUM',
            field=models.CharField(max_length=8, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='TOP_DISB_FLG',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='TRANSFER_TYPE',
            field=models.CharField(max_length=1, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='TRAN_ID',
            field=models.CharField(max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name='roboltdview',
            name='TYPE_OF_DMDS',
            field=models.CharField(max_length=1, null=True),
        ),
    ]
