# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-07-13 05:36
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0012_robocollectionfdv'),
    ]

    operations = [
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='ADVICE_OUTSTANDING_REPAYMENT_FEE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='BCC_DUE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='BCC_PAID',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='INSTALLMENT',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='INTEREST_DUE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='INTEREST_PAID',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='LPC_DUE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='LPC_PAID',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='NET_TOTAL',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='OTHER_DUE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='OTHER_PAID',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='OVERDUE_CHARGES',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='PREPAYMENT_PENALTY',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='PREPAYPENALTY_DUE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='PREPAYPENALTY_PAID',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='PREPAYPENALTY_PERCENT',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='PRINCIPAL_BALANCE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='PRINCIPAL_DUE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='PRINCIPAL_PAID',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='REFUNDS',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='TENTATIVE_FORECLOSURE_AMT',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='TOTAL_RECEIVABLE',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
        migrations.AlterField(
            model_name='robocollectionfdv',
            name='UNBILLED_INSTALLMENT',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=17, null=True),
        ),
    ]
